@@ -49,6 +50,7 @@ import alert from "@/ux-components/alert/alert";
import questionChain from "@/common-components/question-chain/question-chain";
import funnelSubHeader from "@/common-components/funnel-sub-header/funnel-sub-header";
import funnelFooter from "@/common-components/funnel-footer/funnel-footer";
+import loadingModal from '@/common-components/loading-modal/loading-modal.vue';
// Supporting Files
import { fetchCmsContentForPage } from "@/helpers/cms-content-helper";
@@ -145,6 +147,7 @@ export default {
questionChain,
funnelSubHeader,
funnelFooter,
+ loadingModal,
Form,
},
};
diff --git a/src/layouts/vehicle-parts/vehicle-parts.vue b/src/layouts/vehicle-parts/vehicle-parts.vue
index 3cbc07e6f..832d4bb94 100644
--- a/src/layouts/vehicle-parts/vehicle-parts.vue
+++ b/src/layouts/vehicle-parts/vehicle-parts.vue
@@ -1,6 +1,7 @@
diff --git a/src/layouts/molding-questions/molding-questions.vue b/src/layouts/molding-questions/molding-questions.vue
index a0fa5e96d..c489dc500 100644
--- a/src/layouts/molding-questions/molding-questions.vue
+++ b/src/layouts/molding-questions/molding-questions.vue
@@ -6,6 +6,7 @@
v-slot="{ meta }"
>
+
@@ -49,6 +50,7 @@ import alert from "@/ux-components/alert/alert";
import questionChain from "@/common-components/question-chain/question-chain";
import funnelSubHeader from "@/common-components/funnel-sub-header/funnel-sub-header";
import funnelFooter from "@/common-components/funnel-footer/funnel-footer";
+import loadingModal from '@/common-components/loading-modal/loading-modal.vue';
// Supporting Files
import { fetchCmsContentForPage } from "@/helpers/cms-content-helper";
@@ -159,8 +161,9 @@ export default {
const collectedGlassParts = this.reduceGlassPartsArray(glassNameAndPartsForStore);
// save to store lineItems.glassParts
this.$store.commit(storeMutations.UPDATE_GLASS_PARTS, collectedGlassParts);
- // go to quote page
- this.$router.navigate(this.navigationScenarios.ANSWERED_QUESTIONS_WITH_SINGLE_PART,this.$route);
+ // go to heritage quote page
+ this.$refs.loadingModal.showModal();
+ navigateToHeritageFunnel();
}
},
},
@@ -180,6 +183,7 @@ export default {
questionChain,
funnelSubHeader,
funnelFooter,
+ loadingModal,
Form,
},
};
diff --git a/src/layouts/part-questions/part-questions.vue b/src/layouts/part-questions/part-questions.vue
index b22c30ba6..dcefad7c0 100644
--- a/src/layouts/part-questions/part-questions.vue
+++ b/src/layouts/part-questions/part-questions.vue
@@ -6,6 +6,7 @@
v-slot="{ meta }"
>
+
@@ -49,6 +50,7 @@ import alert from "@/ux-components/alert/alert";
import questionChain from "@/common-components/question-chain/question-chain";
import funnelSubHeader from "@/common-components/funnel-sub-header/funnel-sub-header";
import funnelFooter from "@/common-components/funnel-footer/funnel-footer";
+import loadingModal from '@/common-components/loading-modal/loading-modal.vue';
// Supporting Files
import { fetchCmsContentForPage } from "@/helpers/cms-content-helper";
@@ -61,6 +63,7 @@ import { Form, defineRule } from "vee-validate";
import { required } from "@/helpers/validation-rules";
import { errorMessages } from "@/constants/error-messages";
import vehicleQuestionsMixin from "@/mixins/vehicle-questions-mixin";
+import loadingModal from '@/common-components/loading-modal/loading-modal.vue';
// DEFINE VALIDATION RULES
defineRule("questions-required", required(errorMessages.OPTION_REQUIRED));
@@ -166,8 +169,9 @@ export default {
const collectedGlassParts = this.reduceGlassPartsArray(glassNameAndPartsForStore);
// save to store lineItems.glassParts
this.$store.commit(storeMutations.UPDATE_GLASS_PARTS, collectedGlassParts);
- // go to quote page
- this.$router.navigate(this.navigationScenarios.ANSWERED_QUESTIONS_WITH_SINGLE_PART,this.$route);
+ // go to heritage quote page
+ this.$refs.loadingModal.showModal();
+ navigateToHeritageFunnel();
}
},
arePagePrerequisitesValid() {
@@ -190,6 +194,7 @@ export default {
questionChain,
funnelSubHeader,
funnelFooter,
+ loadingModal,
Form,
},
};